@@ -5,8 +5,6 @@
 if [ `uname` == Darwin ]; then
     if [ "$PY_VER" == "2.7" ]; then
         WHL_FILE=https://pypi.org/packages/cp27/c/catboost/catboost-${PKG_VERSION}-cp27-none-macosx_10_6_intel.macosx_10_9_intel.macosx_10_9_x86_64.macosx_10_10_intel.macosx_10_10_x86_64.whl
-    elif [ "$PY_VER" == "3.4" ]; then
-        WHL_FILE=https://pypi.org/packages/cp34/c/catboost/catboost-${PKG_VERSION}-cp34-none-macosx_10_6_intel.macosx_10_9_intel.macosx_10_9_x86_64.macosx_10_10_intel.macosx_10_10_x86_64.whl
     elif [ "$PY_VER" == "3.5" ]; then
         WHL_FILE=https://pypi.org/packages/cp35/c/catboost/catboost-${PKG_VERSION}-cp35-none-macosx_10_6_intel.macosx_10_9_intel.macosx_10_9_x86_64.macosx_10_10_intel.macosx_10_10_x86_64.whl
     elif [ "$PY_VER" == "3.6" ]; then
@@ -17,8 +15,6 @@ fi
 if [ `uname` == Linux ]; then
     if [ "$PY_VER" == "2.7" ]; then
         WHL_FILE=https://pypi.org/packages/cp27/c/catboost/catboost-${PKG_VERSION}-cp27-none-manylinux1_x86_64.whl
-    elif [ "$PY_VER" == "3.4" ]; then
-        WHL_FILE=https://pypi.org/packages/cp34/c/catboost/catboost-${PKG_VERSION}-cp34-none-manylinux1_x86_64.whl
     elif [ "$PY_VER" == "3.5" ]; then
         WHL_FILE=https://pypi.org/packages/cp35/c/catboost/catboost-${PKG_VERSION}-cp35-none-manylinux1_x86_64.whl
     elif [ "$PY_VER" == "3.6" ]; then
